function [p, logp] = gausspdf(x, m, C)
% gausspdf Evaluate a multivariate Gaussian density.
% function [p, logp] = gausspdf(x, m, C)
% p(i) = N(X(i,:), m, C) where C = covariance matrix and each ROW of x is a datavector
%
% If X has size Nxd, p has size Nx1, where N = number of examples
[N d] = size(x);
M = repmat(m(:)', N, 1); % replicate mean across rows
denom = (2*pi)^(d/2)*sqrt(abs(det(C)));
xc = x-M;
mahal = sum( (xc * inv(C)) .* xc, 2);
logp = -0.5*mahal - log(denom);
% to avoid dividing by 0, we add epsilon to denominator
p = exp(-0.5*mahal) / (denom+eps);